| Title: | Seamless Access to IMF World Economic Outlook (WEO) Data |
|---|---|
| Description: | Provides tools to download, process, and analyze data from the International Monetary Fund's World Economic Outlook (WEO) database <https://www.imf.org/en/Publications/SPROLLs/world-economic-outlook-databases>. Functions support downloading complete WEO releases, accessing specific economic indicators for selected countries, and listing available data. |
| Authors: | Teal Emery [aut, cre], Teal Insights [cph], Christoph Scheuch [aut] (ORCID: <https://orcid.org/0009-0004-0423-6819>) |
| Maintainer: | Teal Emery <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0.9001 |
| Built: | 2026-05-11 07:58:48 UTC |
| Source: | https://github.com/teal-insights/r-imfweo |
Provides tools to download, process, and analyze data from the International Monetary Fund's World Economic Outlook (WEO) database https://www.imf.org/en/Publications/SPROLLs/world-economic-outlook-databases. Functions support downloading complete WEO releases, accessing specific economic indicators for selected countries, and listing available data.
Maintainer: Teal Emery [email protected]
Authors:
Christoph Scheuch [email protected] (ORCID)
Other contributors:
Teal Insights [copyright holder]
Useful links:
Report bugs at https://github.com/teal-insights/r-imfweo/issues
Reset the Cache
weo_cache_reset()weo_cache_reset()
No return value, called for side effects.
Retrieve data from the IMF World Economic Outlook (WEO) database for specific series, countries, and years.
weo_get( entities = NULL, series = NULL, start_year = 1980L, end_year = NULL, year = NULL, release = NULL, quiet = TRUE )weo_get( entities = NULL, series = NULL, start_year = 1980L, end_year = NULL, year = NULL, release = NULL, quiet = TRUE )
entities |
An optional character vector of ISO3 country codes or country group identifiers. See weo_get_entities. |
series |
A optional character vector of series codes. See weo_get_series. |
start_year |
Minimum year to include. Defaults to 1980. |
end_year |
Maximum year to include. Defaults to current year + 5 years. |
year |
The year of a WEO publication (e.g., 2024). Defaults to latest publication year. |
release |
The release of a WEO publication ("Spring" or "Fall"). Defaults to latest publication release. |
quiet |
A logical indicating whether to print download information. Defaults to TRUE. |
A data frame with columns:
ISO3 country code or country group ID
Entity name
WEO series code
Series name
Units of measurement
Year
Value
# Get GDP growth for selected countries weo_get( entities = c("USA", "GBR", "DEU"), series = "NGDP_RPCH", start_year = 2015, end_year = 2020 )# Get GDP growth for selected countries weo_get( entities = c("USA", "GBR", "DEU"), series = "NGDP_RPCH", start_year = 2015, end_year = 2020 )
Returns a data frame with available entities (countries and country groups) in the WEO database.
weo_get_entities(year = NULL, release = NULL, quiet = TRUE)weo_get_entities(year = NULL, release = NULL, quiet = TRUE)
year |
The year of a WEO publication (e.g., 2024). Defaults to latest publication year. |
release |
The release of a WEO publication ("Spring" or "Fall"). Defaults to latest publication release. |
quiet |
A logical indicating whether to print download information. Defaults to TRUE. |
A data frame with columns:
ISO3 country code or country group ID
Full name of the country or country group
# List all countries and regions weo_get_entities()# List all countries and regions weo_get_entities()
Determines the latest available WEO publication based on the current date.
weo_get_latest_publication(quiet = TRUE)weo_get_latest_publication(quiet = TRUE)
quiet |
A logical indicating whether to print download information. Defaults to TRUE. |
A list with year and release
# List all series weo_get_latest_publication(quiet = FALSE)# List all series weo_get_latest_publication(quiet = FALSE)
Returns a data frame with available series in the WEO database.
weo_get_series(year = NULL, release = NULL, quiet = TRUE)weo_get_series(year = NULL, release = NULL, quiet = TRUE)
year |
The year of a WEO publication (e.g., 2024). Defaults to latest publication year. |
release |
The release of a WEO publication ("Spring" or "Fall"). Defaults to latest publication release. |
quiet |
A logical indicating whether to print download information. Defaults to TRUE. |
A data frame with columns:
The WEO series ID (e.g., "NGDP_RPCH")
Full name of the series (e.g., "Gross domestic product, constant prices")
Units of measurement
# List all series weo_get_series()# List all series weo_get_series()
Returns a data frame of available WEO publications from 2007 onwards. The IMF typically releases the WEO database twice per year:
Spring (April)
Fall (October)
weo_list_publications( start_year = 2007, end_year = as.integer(format(Sys.Date(), "%Y")), check_latest = FALSE )weo_list_publications( start_year = 2007, end_year = as.integer(format(Sys.Date(), "%Y")), check_latest = FALSE )
start_year |
Minimum year to include. Defaults to 2007. |
end_year |
Maximum year to include. Defaults to current year. |
check_latest |
Logical indicating whether to check whether the latest publication according to current date has been released. Defaults to FALSE. |
A data frame with columns:
The year of the release
The release name ("Spring" or "Fall")
The month of release ("April" or "October")
weo_list_publications(check_latest = TRUE)weo_list_publications(check_latest = TRUE)